Documentation
¶
Index ¶
- Variables
- type Datadog
- func (*Datadog) Descriptor() ([]byte, []int)deprecated
- func (x *Datadog) GetApiKey() string
- func (x *Datadog) GetAppKey() string
- func (x *Datadog) GetEnabled() *wrapperspb.BoolValue
- func (x *Datadog) GetTags() []string
- func (*Datadog) ProtoMessage()
- func (x *Datadog) ProtoReflect() protoreflect.Message
- func (x *Datadog) Reset()
- func (x *Datadog) String() string
- type MetricStores
- func (*MetricStores) Descriptor() ([]byte, []int)deprecated
- func (x *MetricStores) GetDatadog() *Datadog
- func (x *MetricStores) GetNewrelic() *Newrelic
- func (x *MetricStores) GetPeriod() int32
- func (x *MetricStores) GetPrometheus() *Prometheus
- func (x *MetricStores) GetStackdriver() *Stackdriver
- func (*MetricStores) ProtoMessage()
- func (x *MetricStores) ProtoReflect() protoreflect.Message
- func (x *MetricStores) Reset()
- func (x *MetricStores) String() string
- type Newrelic
- func (*Newrelic) Descriptor() ([]byte, []int)deprecated
- func (x *Newrelic) GetEnabled() *wrapperspb.BoolValue
- func (x *Newrelic) GetHost() string
- func (x *Newrelic) GetInsertKey() string
- func (x *Newrelic) GetTags() []string
- func (*Newrelic) ProtoMessage()
- func (x *Newrelic) ProtoReflect() protoreflect.Message
- func (x *Newrelic) Reset()
- func (x *Newrelic) String() string
- type Prometheus
- func (*Prometheus) Descriptor() ([]byte, []int)deprecated
- func (x *Prometheus) GetEnabled() *wrapperspb.BoolValue
- func (x *Prometheus) GetPushGateway() string
- func (*Prometheus) ProtoMessage()
- func (x *Prometheus) ProtoReflect() protoreflect.Message
- func (x *Prometheus) Reset()
- func (x *Prometheus) String() string
- type Stackdriver
- func (*Stackdriver) Descriptor() ([]byte, []int)deprecated
- func (x *Stackdriver) GetCredentialsPath() string
- func (x *Stackdriver) GetEnabled() *wrapperspb.BoolValue
- func (x *Stackdriver) GetProject() string
- func (x *Stackdriver) GetZone() string
- func (*Stackdriver) ProtoMessage()
- func (x *Stackdriver) ProtoReflect() protoreflect.Message
- func (x *Stackdriver) Reset()
- func (x *Stackdriver) String() string
Constants ¶
This section is empty.
Variables ¶
var File_metricstores_datadog_proto protoreflect.FileDescriptor
var File_metricstores_metricstores_proto protoreflect.FileDescriptor
var File_metricstores_newrelic_proto protoreflect.FileDescriptor
var File_metricstores_prometheus_proto protoreflect.FileDescriptor
var File_metricstores_stackdriver_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Datadog ¶
type Datadog struct {
// Whether the Datadog metric store is enabled.
Enabled *wrapperspb.BoolValue `protobuf:"bytes,1,opt,name=enabled,proto3" json:"enabled,omitempty"`
// Datadog API key.
ApiKey string `protobuf:"bytes,2,opt,name=apiKey,json=api_key,proto3" json:"apiKey,omitempty"`
// Datadog app key. Only required if you want Spinnaker to push pre-configured
// Spinnaker dashboards to your Datadog account.
AppKey string `protobuf:"bytes,3,opt,name=appKey,json=app_key,proto3" json:"appKey,omitempty"`
// Datadog custom tags. Delimit the key-value pair with colons
// (e.g., `app:test`).
Tags []string `protobuf:"bytes,4,rep,name=tags,proto3" json:"tags,omitempty"`
// contains filtered or unexported fields
}
Configuration for the Datadog metric store.
func (*Datadog) Descriptor
deprecated
func (*Datadog) GetEnabled ¶
func (x *Datadog) GetEnabled() *wrapperspb.BoolValue
func (*Datadog) ProtoMessage ¶
func (*Datadog) ProtoMessage()
func (*Datadog) ProtoReflect ¶
func (x *Datadog) ProtoReflect() protoreflect.Message
type MetricStores ¶
type MetricStores struct {
// Configuration for the Datadog metric store.
Datadog *Datadog `protobuf:"bytes,1,opt,name=datadog,proto3" json:"datadog,omitempty"`
// Configuration for the Newrelic metric store.
Newrelic *Newrelic `protobuf:"bytes,2,opt,name=newrelic,proto3" json:"newrelic,omitempty"`
// Configuration for the Prometheus metric store.
Prometheus *Prometheus `protobuf:"bytes,3,opt,name=prometheus,proto3" json:"prometheus,omitempty"`
// Configuration for the Stackdriver metric store.
Stackdriver *Stackdriver `protobuf:"bytes,4,opt,name=stackdriver,proto3" json:"stackdriver,omitempty"`
// Polling period for the monitoring daemon (seconds). Defaults to 30.
Period int32 `protobuf:"varint,5,opt,name=period,proto3" json:"period,omitempty"`
// contains filtered or unexported fields
}
Configuration for the Spinnaker monitoring daemon metric stores.
func (*MetricStores) Descriptor
deprecated
func (*MetricStores) Descriptor() ([]byte, []int)
Deprecated: Use MetricStores.ProtoReflect.Descriptor instead.
func (*MetricStores) GetDatadog ¶
func (x *MetricStores) GetDatadog() *Datadog
func (*MetricStores) GetNewrelic ¶
func (x *MetricStores) GetNewrelic() *Newrelic
func (*MetricStores) GetPeriod ¶
func (x *MetricStores) GetPeriod() int32
func (*MetricStores) GetPrometheus ¶
func (x *MetricStores) GetPrometheus() *Prometheus
func (*MetricStores) GetStackdriver ¶
func (x *MetricStores) GetStackdriver() *Stackdriver
func (*MetricStores) ProtoMessage ¶
func (*MetricStores) ProtoMessage()
func (*MetricStores) ProtoReflect ¶
func (x *MetricStores) ProtoReflect() protoreflect.Message
func (*MetricStores) Reset ¶
func (x *MetricStores) Reset()
func (*MetricStores) String ¶
func (x *MetricStores) String() string
type Newrelic ¶
type Newrelic struct {
// Whether the New Relic metric store is enabled.
Enabled *wrapperspb.BoolValue `protobuf:"bytes,1,opt,name=enabled,proto3" json:"enabled,omitempty"`
// Your New Relic Insights insert key.
InsertKey string `protobuf:"bytes,2,opt,name=insertKey,json=insert_key,proto3" json:"insertKey,omitempty"`
// The URL to post metric data to. In almost all cases, this is set correctly
// by default and should not be used.
Host string `protobuf:"bytes,3,opt,name=host,proto3" json:"host,omitempty"`
// New Relic custom tags. Delimit the key-value pair with colons
// (e.g., `app:test`).
Tags []string `protobuf:"bytes,4,rep,name=tags,proto3" json:"tags,omitempty"`
// contains filtered or unexported fields
}
Configuration for the New Relic metric store.
func (*Newrelic) Descriptor
deprecated
func (*Newrelic) GetEnabled ¶
func (x *Newrelic) GetEnabled() *wrapperspb.BoolValue
func (*Newrelic) GetInsertKey ¶
func (*Newrelic) ProtoMessage ¶
func (*Newrelic) ProtoMessage()
func (*Newrelic) ProtoReflect ¶
func (x *Newrelic) ProtoReflect() protoreflect.Message
type Prometheus ¶
type Prometheus struct {
// Whether the Prometheus metric store is enabled.
Enabled *wrapperspb.BoolValue `protobuf:"bytes,1,opt,name=enabled,proto3" json:"enabled,omitempty"`
// The endpoint to which the monitoring Daemon should push metrics. If you
// have configured Prometheus to automatically discover all your Spinnaker
// services and pull metrics from them, this is not required.
PushGateway string `protobuf:"bytes,2,opt,name=pushGateway,json=push_gateway,proto3" json:"pushGateway,omitempty"`
// contains filtered or unexported fields
}
Configuration for the Prometheus metric store.
func (*Prometheus) Descriptor
deprecated
func (*Prometheus) Descriptor() ([]byte, []int)
Deprecated: Use Prometheus.ProtoReflect.Descriptor instead.
func (*Prometheus) GetEnabled ¶
func (x *Prometheus) GetEnabled() *wrapperspb.BoolValue
func (*Prometheus) GetPushGateway ¶
func (x *Prometheus) GetPushGateway() string
func (*Prometheus) ProtoMessage ¶
func (*Prometheus) ProtoMessage()
func (*Prometheus) ProtoReflect ¶
func (x *Prometheus) ProtoReflect() protoreflect.Message
func (*Prometheus) Reset ¶
func (x *Prometheus) Reset()
func (*Prometheus) String ¶
func (x *Prometheus) String() string
type Stackdriver ¶
type Stackdriver struct {
// Whether the Datadog metric store is enabled.
Enabled *wrapperspb.BoolValue `protobuf:"bytes,1,opt,name=enabled,proto3" json:"enabled,omitempty"`
// Path to a Google JSON service account that has permission to publish
// metrics.
CredentialsPath string `protobuf:"bytes,2,opt,name=credentialsPath,json=credentials_path,proto3" json:"credentialsPath,omitempty"`
// The project to which Spinnaker's metrics should be published.
Project string `protobuf:"bytes,3,opt,name=project,proto3" json:"project,omitempty"`
// The zone with which Spinnaker's metrics should be associated.
Zone string `protobuf:"bytes,4,opt,name=zone,proto3" json:"zone,omitempty"`
// contains filtered or unexported fields
}
Configuration for the Stackdriver metric store.
func (*Stackdriver) Descriptor
deprecated
func (*Stackdriver) Descriptor() ([]byte, []int)
Deprecated: Use Stackdriver.ProtoReflect.Descriptor instead.
func (*Stackdriver) GetCredentialsPath ¶
func (x *Stackdriver) GetCredentialsPath() string
func (*Stackdriver) GetEnabled ¶
func (x *Stackdriver) GetEnabled() *wrapperspb.BoolValue
func (*Stackdriver) GetProject ¶
func (x *Stackdriver) GetProject() string
func (*Stackdriver) GetZone ¶
func (x *Stackdriver) GetZone() string
func (*Stackdriver) ProtoMessage ¶
func (*Stackdriver) ProtoMessage()
func (*Stackdriver) ProtoReflect ¶
func (x *Stackdriver) ProtoReflect() protoreflect.Message
func (*Stackdriver) Reset ¶
func (x *Stackdriver) Reset()
func (*Stackdriver) String ¶
func (x *Stackdriver) String() string
Click to show internal directories.
Click to hide internal directories.